quietly{
cls
noisily di as err "This do file contains the data analysis used in the paper 'Overconfidence and Preferences for Competition' by Ernesto Reuben, Paola Sapienza, and Luigi Zingales"
noisily di as txt "It includes the Stata code that generates all figures and tables in the main body of the paper and data-related statements mmade in the main text."
noisily di as txt "To run, the dataset 'overconf_prefcompetition.dta' needs to be in the same folder."
noisily di as txt "Note that the file also include code to generate the Tables in tex format but this has been commented out."
noisily di as txt "It was run with Stata SE version 16.1"
noisily di " "

ssc install estout, replace
ssc install erepost, replace
version 16.1

// Create frames for the data anlaysis and load dataset.
clear all
frames create regdata
frames create statstable
frames create graphdata
frames change regdata
use overconf_prefcompetition.dta, replace

// Prepare summary statistics for Table I. The code outputs the table and makes the tex version.
noisily di " "
// *********************************************************
noisily di as err "*** Table I – Descriptive statistics ***"
// *********************************************************

frame copy regdata statstable, replace
frame change statstable
foreach var in salary08 basesalary08 bonuspay08 bonus_onetime08 bonus_perform08 salary15 basesalary15 bonuspay15 salary08w salary15w{
  replace `var' = `var' / 1000
}
la var competitive "Competitive"
la var perform "Performance"
la var erank "Expected rank in adding tasks"
la var expprofit "Expected experimental earnings"
la var overconf "Overconfidence"
la var riskCRRA "Risk aversion coefficient"
la var nocompetepay "Non-competitive tournament"
la var salary08 "Total income"
la var basesalary08 "Base salary"
la var bonuspay08 "Total bonus"
la var bonus_onetime08 "One-off bonus"
la var bonus_perform08 "Guaranteed performance bonus"
la var ind_fin08 "Working in finance"
la var ind_consulting08 "Working in consulting"
la var salary15 "Total income"
la var basesalary15 "Base salary"
la var bonuspay15 "Performance bonus"
la var ind_fin15 "Working in finance"
la var ind_consulting15 "Working in consulting"
la var numjobs15 "Number of jobs"
la var numpromotions15 "Number of promotions"
la var hourswork15 "Hours worked per week"
la var workbreak15 "Had a career interruption"

local hbar = "-"
forvalues x = 0(1)85{
  local hbar = "`hbar'-"
}
noisily di as txt "`hbar'"
local varname = "Men               Women"
forvalues x = 0(1)55{
  local varname = " `varname'"
}
noisily di as txt "`varname'"
local varname = "Avg   s.d.  N     Avg   s.d.  N  p-val"
forvalues x = 0(1)47{
  local varname = " `varname'"
}
noisily di as txt "`varname'"
noisily di as txt "`hbar'"

// file open myfile using "tableI.tex", write replace
// file write myfile "{" _n "\begin{tabular}{l d{3.2} d{3.2} c@{ }c d{3.2} d{3.2} c@{ }c d{1.3}}" _n "\toprule " _n " & \multicolumn{3}{c}{Men} && \multicolumn{3}{c}{Women} \\ \cmidrule{2-4} \cmidrule{6-8} " _n
// file write myfile " & \multicolumn{1}{c}{mean} & \multicolumn{1}{c}{s.d.} & \multicolumn{1}{c}{N} && \multicolumn{1}{c}{mean} & \multicolumn{1}{c}{s.d.} & \multicolumn{1}{c}{N} && \multicolumn{1}{c}{\textit{p}-value} \\ \midrule " _n
// file write myfile "\textit{Experiment} \\ " _n

foreach stub in competitive perform erank expprofit overconf riskCRRA nocompetepay salary08 basesalary08 bonuspay08 bonus_onetime08 bonus_perform08 ind_fin08 ind_consulting08 salary15 basesalary15 bonuspay15 ind_fin15 ind_consulting15 numjobs15 numpromotions15 hourswork15 workbreak15{

  local varname: variable label `stub'
		sum `stub' if gender==0
		local M0 = strofreal(r(mean),"%9.2f")
		local SD0 = strofreal(r(sd),"%9.2f")
		local N0 = strofreal(r(N),"%9.0f")
    local range0 = r(max) - r(min)
		sum `stub' if gender==1
		local M1 = strofreal(r(mean),"%9.2f")
		local SD1 = strofreal(r(sd),"%9.2f")
    local N1 = strofreal(r(N),"%9.0f")
    local range1 = r(max) - r(min)

		if `range0' == 1 & `range1' == 1{
			tab `stub' gender, co chi e
		}
		else{
			ttest `stub', by(gender) une
		}
    local pval = strofreal(r(p),"%9.3f")

    // file write myfile "`varname' & `M0' & `SD0' & `N0' && `M1' & `SD1' & `N1' && `pval'\\ " " " _n
    // if "`stub'" == "nocompetepay"{ 
      // file write myfile "\midrule " _n "\textit{Jobs data in 2008} \\ " _n
    // }
    // if "`stub'" == "ind_consulting08"{ 
      // file write myfile "\midrule " _n "\textit{Jobs data in 2015} \\ " _n
    // }
    
    local blanks = 43 - strlen("`varname'")
    forvalues x = 0(1)`blanks'{
      local varname = "`varname' "
    }
    local blanks = 5 - strlen("`M0'")
    forvalues x = 0(1)`blanks'{
      local M0 = " `M0'"
    }
    local blanks = 5 - strlen("`M1'")
    forvalues x = 0(1)`blanks'{
      local M1 = " `M1'"
    }
    local blanks = 5 - strlen("`SD0'")
    forvalues x = 0(1)`blanks'{
      local SD0 = " `SD0'"
    }
    local blanks = 5 - strlen("`SD1'")
    forvalues x = 0(1)`blanks'{
      local SD1 = " `SD1'"
    }

    noisily di "`varname' `M0' `SD0' `N0' `M1' `SD1' `N1' `pval'"
}
noisily di as txt "`hbar'"

// file write myfile "\bottomrule " _n "\end{tabular} " _n "}" _n
// file close myfile

// Prepare regressions for Table II. The code outputs the table and makes the tex version.
noisily di " "
// *************************************************************************
noisily di as err "*** Table II – Determinants of Willingness to Compete ***"
// *************************************************************************
frame change regdata
replace perform = -perform

foreach var in overconf riskCRRA perform {
  egen `var'_std = std(`var')
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

probit competitive i.gender, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab2I: margins, dydx(1.gender) atmeans post
  estadd local Ochi2 `orgchi2'
probit competitive i.gender perform_std, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab2II: margins, dydx(1.gender perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
probit competitive i.gender perform_std overconf_std riskCRRA_std, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab2III: margins, dydx(1.gender perform_std overconf_std riskCRRA_std) atmeans post
  estadd local Ochi2 `orgchi2'

noisily estout tab2I tab2II tab2III, keep(1.gender perform_std riskCRRA_std overconf_std) cells(b(star fmt(%9.3f)) se(par)) stats(N Ochi2, fmt(%9.0g %9.3f)) collabels(none) starlevels(* 0.10 ** 0.05 *** 0.01) label mlabels("(1)" "(2)" "(3)")

// esttab tab2I tab2II tab2III using "tableII.tex", replace keep(1.gender perform_std riskCRRA_std overconf_std) label booktabs nogaps noobs nonotes nomtitle alignment(D{.}{.}{-1}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "Ochi2 \$\chi^2\$ test") sfmt(0 3) 

// Prepare summary statistics for Table III. The code outputs the table and makes the tex version.
noisily di " "
// ***********************************************************
noisily di as err "*** Table III – Industry characteristics ***"
// ***********************************************************

frame change statstable

local hbar = "-"
forvalues x = 0(1)65{
  local hbar = "`hbar'-"
}

noisily di as err "Panel A – Income and bonus pay"
noisily di as txt "`hbar'"
local varname = "Fin   Cons   Comp   Other"
forvalues x = 0(1)41{
  local varname = " `varname'"
}
noisily di as txt "`varname'"
noisily di as txt "`hbar'"

// file open myfile using "tableIII.tex", write replace
// file write myfile "{" _n "\begin{tabular}{l d{3.2} d{3.2} d{3.2} d{3.2} }" _n "\toprule " _n " & \multicolumn{1}{c}{Finance} & \multicolumn{1}{c}{Consulting} & \multicolumn{1}{c}{\parbox{1.9cm}{Finance or Consulting}} & \multicolumn{1}{c}{Other} \\ \midrule " _n

foreach yr in 08 15{
	local varname = "Mean total income in 20`yr'"
	local x = 1
	foreach col in "==1" "==2" "!=0" "==0"{
		sum salary`yr'w if ind`yr'`col' & ind`yr' < .
		local M`x' = strofreal(r(mean),"%9.2f")
		local x = `x' + 1
	}
	// file write myfile "`varname' & `M1' & `M2' & `M3' & `M4' \\ " " " _n
	noisily di "`varname'               `M1' `M2' `M3' `M4'"
	local varname = "Fraction of income in 20`yr' from bonuses"
	local x = 1
	foreach col in "==1" "==2" "!=0" "==0"{
		sum bonusfrac`yr'w if ind`yr'`col' & ind`yr' < .
		local M`x' = strofreal(r(mean),"%9.2f")
		local x = `x' + 1
	}
	// file write myfile "`varname' & `M1' & `M2' & `M3' & `M4' \\ " " " _n
	noisily di "`varname'   `M1'   `M2'   `M3'   `M4'"
}
noisily di as txt "`hbar'"
// file write myfile "\bottomrule " _n "\end{tabular} " _n "}" _n

noisily di as err "Panel B – Industry transitions"
noisily di as txt "`hbar'"

// file write myfile "{" _n "\begin{tabular}{l d{3.2} d{3.2} d{3.2} d{3.2} }" _n "\toprule " _n " & \multicolumn{4}{c}{Fraction in 2015 who is working in:} \\ " _n " & \multicolumn{1}{c}{Finance} & \multicolumn{1}{c}{Consulting} & \multicolumn{1}{c}{\parbox{1.9cm}{Finance or Consulting}} & \multicolumn{1}{c}{Other} \\ \midrule " _n

foreach rowvar in 1 2 0{
	if `rowvar' == 1 { 
		local ind = "Finance"
	} 
	else if `rowvar' == 2 {
		local ind = "Consulting"
	} 
	else {
		local ind = "Other"
	} 
	local varname = "Started in `ind' in 2008"
	local x = 1
	foreach col in ind_fin15 ind_consulting15 ind_compete15{
		sum `col' if ind08==`rowvar'
		local M`x' = strofreal(r(mean),"%9.2f")
		local x = `x' + 1
	}
	// local m4 = 1 - `M3'
	local M4 = strofreal(1 - `M3',"%9.2f")
	// file write myfile "`varname' & `M1' & `M2' & `M3' & `M4' \\ " " " _n
	noisily di "`varname' `M1' `M2' `M3' `M4'"
}
noisily di as txt "`hbar'"
// file write myfile "\bottomrule " _n "\end{tabular} " _n "}" _n
// file close myfile

ttest salary08w if ind08!=1, by(ind08)
local perdiff = strofreal(100 * r(mu_2)/r(mu_1) - 100,"%9.0f")
local pval = strofreal(r(p),"%9.3f")
noisily di as txt "Income in 2008 is higher in consulting by `perdiff'% (p = `pval')" 

ttest salary08w if ind08!=2, by(ind08)
local perdiff = strofreal(100 * r(mu_2)/r(mu_1) - 100,"%9.0f")
local pval = strofreal(r(p),"%9.3f")
noisily di as txt "Income in 2008 is higher in finance by `perdiff'% (p = `pval')" 

ttest salary15w if ind15!=1, by(ind15)
local perdiff = strofreal(100 * r(mu_2)/r(mu_1) - 100,"%9.0f")
local pval = strofreal(r(p),"%9.3f")
noisily di as txt "Income in 2015 is higher in consulting by `perdiff'% (p = `pval')" 

ttest salary15w if ind15!=2, by(ind15)
local perdiff = strofreal(100 * r(mu_2)/r(mu_1) - 100,"%9.0f")
local pval = strofreal(r(p),"%9.3f")
noisily di as txt "Income in 2015 is higher in finance by `perdiff'% (p = `pval')" 

// Prepare regressions for Table IV. The code outputs the table and makes the tex version.
noisily di " "
// *****************************************************************************
noisily di as err "*** Table IV – Determinants of earnings in the experiment ***"
// *****************************************************************************
frame change regdata

gen lnexpprofit = ln(expprofit)
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var')
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab4I: reg lnexpprofit 1.competitive, r
eststo tab4II: reg lnexpprofit 1.competitive c.perform_std, r
eststo tab4III: reg lnexpprofit 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
eststo tab4IV: reg lnexpprofit 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, r
local coef = strofreal(e(b)[1,2]/e(b)[1,4],"%9.3f")

noisily esttab tab4I tab4II tab4III tab4IV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "p P-val" "r2 R-sqrt") sfmt(0 2 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std perform_std) order(1.competitive perform_std 1.gender riskCRRA_std overconf_std 1.competitive#c.overconf_std) label

// esttab tab4I tab4II tab4III tab4IV using "tableIV.tex", replace label booktabs nogaps noobs nonotes nomtitle alignment(D{.}{.}{-1}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "r2 \$R^2\$") sfmt(0 3 3) keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std perform_std) order(1.competitive perform_std 1.gender riskCRRA_std overconf_std 1.competitive#c.overconf_std)

di as txt "A `coef' standard deviation in overconfidence eliminates the positive effect of preferences for competition."

// Prepare Figure 1. The code outputs the graph and makes the png version.

// ******************************************************************
// *** Figure 1 - Total compensation in 2008 by tournament choice ***
// ******************************************************************
frame copy regdata graphdata, replace
frame change graphdata
gen salary = max(min(salary08/1000, 300), 75)
contract salary competitive, zero
egen freqtot = sum(_freq), by(competitive)
egen id = rank(salary), by(competitive)
tsset competitive id
gen cearnper = 100 + 100 * _freq / freqtot if id == 1
replace cearnper = 100 * _freq / freqtot + L.cearnper if id > 1
gen cearnperdrop = cearnper if competitive == 1 & (salary==110 | salary==150 | salary==200)
replace cearnperdrop = cearnper if competitive == 0 & (salary==118.75 | salary==155 | salary==225)
graph set window fontface "CMU Serif"
twoway (dropline cearnperdrop salary if competitive==1, msymbol(none) lcolor(erose) lwidth(medium) lpattern(dash)) (dropline cearnperdrop salary if competitive==0, msymbol(none) lcolor(forest_green*1.1) lwidth(medium) lpattern(dash)) (line cearnper salary if competitive==1, lcolor(erose) lwidth(thick) connect(stairstep)) (line cearnper salary if competitive==0, lcolor(forest_green*1.1) lwidth(thick) connect(stairstep)), ytitle("") yscale(noline) ylabel(100 "0%" 110 "10%" 150 "50%" 190 "90%" 200 "100%", labsize(medium) angle(horizontal) noticks glcolor(gs13) gmin gmax) xtitle("") xscale(range(75 300)) xscale(noline) xlabel(110 "110k" 119 "119k" 150 "150k" 155 "155k" 200 "200k" 225 "225k", labsize(medium) labgap(zero) noticks alternate) legend(order(4 "  Piece-rate" 3 "Tournament") textfirst symplacement(center) stack position(4) ring(0) cols(1) rowgap(huge) keygap(zero) size(large) region(fcolor(none) margin(zero) lcolor(none)) bmargin(0 0 10 0)) graphregion(margin(small) fcolor(white) lcolor(white)) plotregion(margin(tiny) lcolor(white)) name(figure1B, replace) xsize(10) ysize(10)
// graph export figure1B.png, as(png) replace

frame copy regdata graphdata, replace
centile salary08, c(1 99)
gen salary = cond(salary08 > r(c_2), r(c_2), cond(salary08 < r(c_1), r(c_1), salary08)) / 1000 if salary08 < .
ttest salary, by(competitive)
local pval = strofreal(r(p),"%9.3f")
// fprank salary, by(competitive)
collapse salary (sem) salaryse=salary (count) nobs=salary, by(competitive)
gen salary_ll = salary - salaryse * invt(nobs, 0.975)
gen salary_ul = salary + salaryse * invt(nobs, 0.975)
set obs 4
replace competitive = mod(_n, 2) if competitive==.
sort competitive salary
gen pline = cond(salary<., 193 + competitive * 5, 198 - competitive * 5)
twoway (bar salary competitive if competitive==0, sort fcolor(forest_green) lwidth(thin) lcolor(black) barwidth(0.60)) (bar salary competitive if competitive==1, sort fcolor(erose*0.6) lwidth(thin) lcolor(black) barwidth(0.60)) (rcap salary_ll salary_ul competitive, sort lcolor(maroon) lwidth(medthick) msize(medium)) (line pline competitive, lcolor(black)), ytitle("") yscale(noline) ylabel(100 "100k" 125 "125k" 150 "150k" 175 "175k" 200 "200k", labsize(medium) angle(horizontal) noticks glcolor(gs13) gmin gmax) xtitle("") xscale(range(-0.75 1.75)) xscale(noline) xlabel(0 "Piece-rate" 1 "Tournament", labsize(large) noticks) legend(off) graphregion(margin(small) fcolor(white) lcolor(white)) plotregion(lcolor(white)) title(, color(black) size(vlarge) span margin(bottom)) text(197 0.5 "{it:p} = `pval'", size(medlarge) place(c) bcolor(white) box) name(figure1A, replace) xsize(10) ysize(10)
// graph export figure1A.png, as(png) replace
frames change regdata
noisily di " "

// Prepare regressions for Table V. The code outputs the table and makes the tex version.
// ***********************************************************************
noisily di as err "*** Table V – Determinants of Compensation in 2008 ***"
// ***********************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary08 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab5AI: reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std
  margins gender competitive
  mat coef = r(b)
  noisily di as txt strofreal((exp(coef[1,2]) - exp(coef[1,1]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (1) (gender)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(coef[1,3]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (1) (competitive)"

eststo tab5AII: reg lnbasesalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std

probit lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5AIII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5AIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0)
  margins gender competitive
  mat coef = r(b)
  noisily di as txt strofreal((exp(coef[1,2]) - exp(coef[1,1]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (4) (gender)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(coef[1,3]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (4) (competitive)"

probit lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5AV: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5AVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0)
  margins gender competitive
  mat coef = r(b)
  noisily di as txt strofreal((exp(coef[1,2]) - exp(coef[1,1]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (6) (gender)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(coef[1,3]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (6) (competitive)"

probit lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5AVII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5AVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0)
  margins gender competitive
  mat coef = r(b)
  noisily di as txt strofreal((exp(coef[1,2]) - exp(coef[1,1]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (8) (gender)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(coef[1,3]))/1000,"%9.1f") + "K difference in USD in Table V Panel A (8) (competitive)"

eststo tab5BI: reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08

eststo tab5BII: reg lnbasesalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08

probit lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5BIII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5BIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

probit lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5BV: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5BVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

probit lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08
  local orgchi2 = round(e(chi2),0.001)
  eststo tab5BVII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab5BVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab5AI tab5AII tab5AIII tab5AIV tab5AV tab5AVI tab5AVII tab5AVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 3 3 3 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std) label

// esttab tab5AI tab5AII tab5AIII tab5AIV tab5AV tab5AVI tab5AVII tab5AVIII using "tableV.tex", replace keep(1.gender 1.competitive overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "Ochi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3) 
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab5BI tab5BII tab5BIII tab5BIV tab5BV tab5BVI tab5BVII tab5BVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std) label

// esttab tab5BI tab5BII tab5BIII tab5BIV tab5BV tab5BVI tab5BVII tab5BVIII using "tableV.tex", append keep(1.gender 1.competitive overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "Ochi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3) 
noisily di " "

reg lnsalary08 1.gender c.overconf_std c.riskCRRA_std c.perform_std
  local gencoef0 = e(b)[1,1]
reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std
  local gencoefnew = round(`gencoef0' * 100, 0.1)
  local gencoefdiff = round(100 * (e(b)[1,1] - `gencoef0'), 0.1)
  local gencoefper = strofreal( 100 * ( (`gencoef0' - e(b)[1,1]) / `gencoef0'), "%9.1f")
  noisily di as txt "The gender coefficient without competitive is `gencoefnew'. Hence, competitive explains `gencoefdiff' log points or `gencoefper'% of the gender gap."

// Prepare regressions for Table VI. The code outputs the table and makes the tex version. Note that the marginal effects for the interaction term are calculated as the change of two marginal effects. Namely, the marginal effect of 'overconfidence' when 'competitive' equals one and the one when 'competitive' equals zero (all other variables at means). The standard error and p-value correspond to testing whether these marginal effects are significantly different from each other.
noisily di " "
// *************************************************************************************************************
noisily di as err "*** Table VI – Interaction between preferences for competition and overconfidence in 2008 ***"
// *************************************************************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary08 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab6AI: reg lnsalary08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std

eststo tab6AII: reg lnbasesalary08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std

probit lnbonuspay08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  forvalues x=1/4{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  mat coef[1,5] = coef2[1,1]
  mat vars[5,5] = vars2[1,1]
  test 0.competitive = 1.competitive
  local pval = r(p)
  mat coef[1,6] = coef2[1,2] - coef2[1,1]
  mat vars[6,6] = (coef[1,6]/invnormal(`pval'/2))^2
  probit lnbonuspay08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6AIII
eststo tab6AIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0)

probit lnbonus_onetime08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  forvalues x=1/4{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  mat coef[1,5] = coef2[1,1]
  mat vars[5,5] = vars2[1,1]
  test 0.competitive = 1.competitive
  local pval = r(p)
  mat coef[1,6] = coef2[1,2] - coef2[1,1]
  mat vars[6,6] = (coef[1,6]/invnormal(`pval'/2))^2
  probit lnbonus_onetime08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6AV

eststo tab6AVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0)

probit lnbonus_perform08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  forvalues x=1/4{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  mat coef[1,5] = coef2[1,1]
  mat vars[5,5] = vars2[1,1]
  test 0.competitive = 1.competitive
  local pval = r(p)
  mat coef[1,6] = coef2[1,2] - coef2[1,1]
  mat vars[6,6] = (coef[1,6]/invnormal(`pval'/2))^2
  probit lnbonus_perform08 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6AVII

eststo tab6AVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0)

eststo tab6BI: reg lnsalary08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08

eststo tab6BII: reg lnbasesalary08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08

probit lnbonuspay08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std ib0.ind08) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/9{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,10] = coef2[1,1]
  mat coef[1,12] = coef2[1,2] - coef2[1,1]
  mat vars[10,10] = vars2[1,1]
  mat vars[12,12] = (coef[1,12]/invnormal(`pval'/2))^2
  probit lnbonuspay08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6BIII

eststo tab6BIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

probit lnbonus_onetime08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std ib0.ind08) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/9{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,10] = coef2[1,1]
  mat coef[1,12] = coef2[1,2] - coef2[1,1]
  mat vars[10,10] = vars2[1,1]
  mat vars[12,12] = (coef[1,12]/invnormal(`pval'/2))^2
  probit lnbonus_onetime08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6BV

eststo tab6BVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

probit lnbonus_perform08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std ib0.ind08) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/9{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,10] = coef2[1,1]
  mat coef[1,12] = coef2[1,2] - coef2[1,1]
  mat vars[10,10] = vars2[1,1]
  mat vars[12,12] = (coef[1,12]/invnormal(`pval'/2))^2
  probit lnbonus_perform08 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind08 c.overconf_std i.competitive#c.overconf_std
  erepost b = coef
  erepost V = vars
  eststo tab6BVII

eststo tab6BVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0)

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab6AI tab6AII tab6AIII tab6AIV tab6AV tab6AVI tab6AVII tab6AVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab6AI tab6AII tab6AIII tab6AIV tab6AV tab6AVI tab6AVII tab6AVIII using "tableVI.tex", replace keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab6BI tab6BII tab6BIII tab6BIV tab6BV tab6BVI tab6BVII tab6BVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab6BI tab6BII tab6BIII tab6BIV tab6BV tab6BVI tab6BVII tab6BVIII using "tableVI.tex", append keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 


// Prepare regressions for Table VII. The code outputs the table and makes the tex version.
noisily di " "
// ***********************************************************************
noisily di as err "*** Table VII – Determinants of Compensation in 2015 ***"
// ***********************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary15 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab7AI: reg lnsalary15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  margins gender competitive
  mat coef = r(b)
  noisily di as txt strofreal((exp(coef[1,2]) - exp(coef[1,1]))/1000,"%9.1f") + "K difference in USD in Table VII Panel A (1) (gender)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(coef[1,3]))/1000,"%9.1f") + "K difference in USD in Table VII Panel A (1) (competitive)"

eststo tab7AII: reg lnbasesalary15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r

probit lnbonuspay15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  local orgchi2 = round(e(chi2),0.01)
  eststo tab7AIII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab7AIV: truncreg lnbonuspay15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

gen bonus_bin = bonuspay15w > 0 if salary15 < .
sum bonus_bin
noisily di as txt strofreal(r(mean) * 100,"%9.0f") + "% receive a bonus in 2015"
sum bonuspay15w if bonuspay15w > 0
noisily di as txt strofreal(r(mean)/1000,"%9.1f") + "K is the average bonus in 2015"

eststo tab7BI: reg lnsalary15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

eststo tab7BII: reg lnbasesalary15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

probit lnbonuspay15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r
  local orgchi2 = round(e(chi2),0.01)
  eststo tab7BIII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
eststo tab7BIV: truncreg lnbonuspay15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, ll(0) r

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab7AI tab7AII tab7AIII tab7AIV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std) label

// esttab tab7AI tab7AII tab7AIII tab7AIV using "tableVII.tex", replace keep(1.gender 1.competitive overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "Ochi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3) 
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab7BI tab7BII tab7BIII tab7BIV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std) label

// esttab tab7BI tab7BII tab7BIII tab7BIV using "tableVII.tex", append keep(1.gender 1.competitive overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "Ochi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3) 

// Prepare regressions for Table VIII. The code outputs the table and makes the tex version. Note that the marginal effects for the interaction term are calculated as the change of two marginal effects. Namely, the marginal effect of 'overconfidence' when 'competitive' equals one and the one when 'competitive' equals zero (all other variables at means). The standard error and p-value correspond to testing whether these marginal effects are significantly different from each other.
noisily di " "
// *************************************************************************************************************
noisily di as err "*** Table VIII – Interaction between preferences for competition and overconfidence in 2015 ***"
// *************************************************************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary15 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab8AI: reg lnsalary15 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std, r
  margins competitive, at(overconf_std=(-1 0 1))
  mat coef = r(b)
  margins
  local avgsalary = r(b)[1,1]
  noisily di as txt strofreal(exp(`avgsalary')/1000,"%9.1f") + "K is the average salary in USD"
  noisily di as txt strofreal((exp(coef[1,2]) - exp(`avgsalary'))/1000,"%9.1f") + "K difference for competitive MBAs with 1 s.d. less overconfidence according to the regression in Table VIII Panel A (1)"
  noisily di as txt strofreal((exp(coef[1,4]) - exp(`avgsalary'))/1000,"%9.1f") + "K difference for competitive MBAs with average overconfidence according to the regression in Table VIII Panel A (1)"
  noisily di as txt strofreal((exp(coef[1,6]) - exp(`avgsalary'))/1000,"%9.1f") + "K difference for competitive MBAs with 1 s.d. more overconfidence according to the regression in Table VIII Panel A (1)"

eststo tab8AII: reg lnbasesalary15 1.gender 1.competitive c.riskCRRA_std c.perform_std c.overconf_std 1.competitive#c.overconf_std, r

probit lnbonuspay15 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/6{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,7] = coef2[1,1]
  mat coef[1,9] = coef2[1,2] - coef2[1,1]
  mat vars[7,7] = vars2[1,1]
  mat vars[9,9] = (coef[1,9]/invnormal(`pval'/2))^2
  probit lnbonuspay15 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab8AIII
eststo tab8AIV: truncreg lnbonuspay15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

eststo tab8BI: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

eststo tab8BII: reg lnbasesalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

probit lnbonuspay15 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind15 c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std ib0.ind15) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/9{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,10] = coef2[1,1]
  mat coef[1,12] = coef2[1,2] - coef2[1,1]
  mat vars[10,10] = vars2[1,1]
  mat vars[12,12] = (coef[1,12]/invnormal(`pval'/2))^2
  probit lnbonuspay15 i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind15 c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab8BIII
eststo tab8BIV: truncreg lnbonuspay15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, ll(0) r

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab8AI tab8AII tab8AIII tab8AIV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab8AI tab8AII tab8AIII tab8AIV using "tableVIII.tex", replace keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab8BI tab8BII tab8BIII tab8BIV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab8BI tab8BII tab8BIII tab8BIV using "tableVIII.tex", append keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 


// **************************************************
// *** Figure 2 – Interaction with overconfidence ***
// **************************************************
mat drop _all
local x = 0
foreach var in lnsalary15 lnbasesalary15 lnbonuspay15{
    sum `var' if `var' > 0
    local overallavg = r(mean)
  	local x = `x' + 1
		local regtype = cond(`x'==3,"truncreg","reg")
    local regopts = cond(`x'==3," ll(0) r", " r")
    `regtype' `var' 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, `regopts'
    margins, dydx(competitive) at(overconf_std=(-2(0.025)2)) noatlegend level(90)
    mat avg = r(b)
		mat var = r(V)
    local ymax = colsof(avg)
    forvalues y=1(1)`ymax'{
      mat graphdata_comp = nullmat(graphdata_comp) \ `x', -2 + (`y' - 1) * 0.025, avg[1,`y'], sqrt(var[`y',`y']), `overallavg'
    }
}
mat colnames graphdata_comp = "variable" "overconf" "avg" "se" "varavg"

sum overconf if lnsalary15 < .
local avg0 = r(mean)
local sd0 = r(sd)
global nooverconf = (0 - `avg0') / `sd0'
forvalues x = 0/1 {
  sum overconf if gender == `x'
  global overavg`x' = (r(mean) - `avg0') / `sd0'
}

frame change graphdata
clear
svmat graphdata_comp, names(col)
la def overconfgraph 1 "Total income in 2015" 2 "Base salary in 2015" 3 "Bonus in 2015"
la val variable overconfgraph
gen cill = exp(varavg + avg - se * invnormal(0.9))/1000 - exp(varavg)/1000
gen ciul = exp(varavg + avg + se * invnormal(0.9))/1000 - exp(varavg)/1000
gen avgsal = exp(varavg + avg)/1000 - exp(varavg)/1000
graph set window fontface "CMU Serif"
twoway (line avgsal overconf, sort lcolor(edkblue) lwidth(thick)) (line cill overconf, lcolor(maroon) lwidth(medthin)) (line ciul overconf if ciul<250, lcolor(maroon) lwidth(medthin)), ytitle("") yscale(noline) yline(0, lwidth(thin) lcolor(black)) ylabel(-150 "-$150K" -100 "-$100K" -50 "-$50K" 0 "$0K" 50 "$50K" 100 "$100K" 150 "$150K" 200 "$200K" 250 "$250K", labsize(large) angle(horizontal) tlcolor(gs13) glwidth(thin) glcolor(gs13) gmin gmax) xtitle(Overconfidence) xtitle(, size(vlarge) margin(top)) xscale(range(-2.4 2.4)) xscale(noline) xline($overavg0, lwidth(thin) lpattern(dash) lcolor(ebblue)) xline($overavg1, lwidth(thin) lpattern(dash) lcolor(erose)) xline($nooverconf, lwidth(thin) lpattern(dash) lcolor(gs3)) xlabel(-2 "-2 s.d." -1 "-1 s.d." 0 "mean" 1 "+1 s.d." 2 "+2 s.d.", labsize(medlarge) tlcolor(gs13)) by(, note("")) by(, legend(off)) name(figure2, replace) xsize(18) ysize(8) by(, graphregion(margin(tiny) color(white) style(none))) by(variable, rows(1)) subtitle(, size(huge) nobox) plotregion(margin(zero) style(none) lcolor(none)) bgcolor(white)
// graph export figure2.png, as(png) replace

frame change regdata
noisily di " "

// Prepare regressions for Table IX. The code outputs the table and makes the tex version.
// *********************************************************************************************
noisily di as err "*** Table IX – Determinants of Compensation in 2008 using the 2015 sample ***"
// *********************************************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary15 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

eststo tab9AI: reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r

eststo tab9AII: reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std 1.competitive#c.overconf_std c.perform_std, r

eststo tab9AIII: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

eststo tab9AIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

eststo tab9AV: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

eststo tab9AVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0) r

eststo tab9AVII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, ll(0)

eststo tab9AVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, ll(0)

eststo tab9BI: reg lnsalary08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, r

eststo tab9BII: reg lnsalary08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, r

eststo tab9BIII: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

eststo tab9BIV: truncreg lnbonuspay08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

eststo tab9BV: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

eststo tab9BVI: truncreg lnbonus_onetime08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

eststo tab9BVII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

eststo tab9BVIII: truncreg lnbonus_perform08 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind08, ll(0) r

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab9AI tab9AII tab9AIII tab9AIV tab9AV tab9AVI tab9AVII tab9AVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab9AI tab9AII tab9AIII tab9AIV tab9AV tab9AVI tab9AVII tab9AVIII using "tableIX.tex", replace keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{1.5}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab9BI tab9BII tab9BIII tab9BIV tab9BV tab9BVI tab9BVII tab9BVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "Ochi2 Chi2-test" "p P-val" "r2 R-sqrt") sfmt(0 2 2 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab9BI tab9BII tab9BIII tab9BIV tab9BV tab9BVI tab9BVII tab9BVIII using "tableIX.tex", append keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{1.5}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3) 
noisily di " "


// Prepare regressions for Table X. The code outputs the table and makes the tex version. Note that the marginal effects for the interaction term are calculated as the change of two marginal effects. Namely, the marginal effect of 'overconfidence' when 'competitive' equals one and the one when 'competitive' equals zero (all other variables at means). The standard error and p-value correspond to testing whether these marginal effects are significantly different from each other.
// *************************************************************************************
noisily di as err "*** Table X – Determinants of working in a competitive industry ***"
// *************************************************************************************

foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var')
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

probit ind_compete08 i.gender i.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab10I: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'

probit ind_compete08 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/6{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,7] = coef2[1,1]
  mat coef[1,9] = coef2[1,2] - coef2[1,1]
  mat vars[7,7] = vars2[1,1]
  mat vars[9,9] = (coef[1,9]/invnormal(`pval'/2))^2
  probit ind_compete08 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab10II

foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if ind15 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

probit ind_compete15 i.gender i.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab10III: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'

probit ind_compete15 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/6{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,7] = coef2[1,1]
  mat coef[1,9] = coef2[1,2] - coef2[1,1]
  mat vars[7,7] = vars2[1,1]
  mat vars[9,9] = (coef[1,9]/invnormal(`pval'/2))^2
  probit ind_compete15 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab10IV

  probit ind_compete15 i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  margins, dydx(competitive) at(overconf_std=(-1 0 1)) atmeans
  mat coef = r(b)
  noisily di as txt strofreal(coef[1,4],"%9.3f") + " is the effect of being competitive on the probability of working in consulting or finance if one is also underconfident according to the regression in Table X (4)"
  noisily di as txt strofreal(coef[1,6],"%9.3f") + " is the effect of being competitive on the probability of working in consulting or finance if one is also overconfident according to the regression in Table X (4)"
noisily di " "

noisily esttab tab10I tab10II tab10III tab10IV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "chi2 Chi2-test" "Ochi2 Org-Chi2") sfmt(0 2 2) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab10I tab10II tab10III tab10IV using "tableX.tex", replace keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "chi2 \$\chi^2\$ test" "Ochi2 \$\chi^2\$ test") sfmt(0 3 3)  mgroups("High-reward industry in 2008" "High-reward industry in 2015", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) span suffix(}) erepeat(\cmidrule(lr){@span}))
noisily di " "


// Prepare regressions for Table XI. The code outputs the table and makes the tex version.

// ***************************************************************************************
noisily di as err "*** Table XI – Determinants of income growth between 2008 and 2015 ***"
// ***************************************************************************************

// Standarize continous independent variables
foreach var in overconf riskCRRA perform {
  drop `var'_std
  egen `var'_std = std(`var') if lnsalary15 < .
}
la var perform_std "Performance"
la var overconf_std "Overconfidence"
la var riskCRRA_std "Risk aversion"

sum lnsalary_grow
local lngrow = r(mean)
sum lnsalary08 if lnsalary15 < .
local ln08 = r(mean)
local lngrowK = strofreal( (exp(`ln08' + `lngrow') - exp(`ln08')) / 1000, "%9.1f")
noisily di as txt strofreal(`lngrow' * 100,"%9.1f") + " log points is the income growth, which equals around `lngrowK'K"

eststo tab11I: reg lnsalary_grow 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  local lngrow_oconf = e(b)[1,3]
  local lngrow_risk = e(b)[1,4]
  margins gender
  mat coef = r(b)
  noisily di as txt strofreal(coef[1,1],"%9.3f") + " log points increse in the income of men"
  noisily di as txt strofreal(coef[1,2],"%9.3f") + " log points increse in the income of women"
  margins, at(overconf_std=(-1 0 1) )
  mat lngrow_oconf = r(b)
  margins, at(riskCRRA_std=(-1 0 1) )
  mat lngrow_risk = r(b)

local lngrowK_oconf = strofreal( ( exp(`ln08' + lngrow_oconf[1,2]) - exp(`ln08' + lngrow_oconf[1,3]) ) / 1000, "%9.1f")
noisily di as txt strofreal(`lngrow_oconf' * 100,"%9.1f") + " log points is the income growth due to overconfidence, which equals around `lngrowK_oconf'K"
local lngrowK_risk = strofreal( ( exp(`ln08' + lngrow_risk[1,2]) - exp(`ln08' + lngrow_risk[1,3]) ) / 1000, "%9.1f")
noisily di as txt strofreal(`lngrow_risk' * 100,"%9.1f") + " log points is the income growth due to risk aversion, which equals around `lngrowK_risk'K"

eststo tab11II: reg lnsalary_grow 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std, r
  margins competitive, at(overconf_std=(-1 0 1) )
  mat lngrow_oconf = r(b)

local lngrowK_oconf = strofreal( ( exp(`ln08' + lngrow_oconf[1,2]) - exp(`ln08') ) / 1000, "%9.1f")
noisily di as txt strofreal(lngrow_oconf[1,2] * 100,"%9.1f") + " log points is the income growth, which equals around `lngrowK_oconf'K for competitive & underconfident according to the regression in Table XI (2)"
local lngrowK_oconf = strofreal( ( exp(`ln08' + lngrow_oconf[1,4]) - exp(`ln08') ) / 1000, "%9.1f")
noisily di as txt strofreal(lngrow_oconf[1,4] * 100,"%9.1f") + " log points is the income growth, which equals around `lngrowK_oconf'K for competitive & precise according to the regression in Table XI (2)"
local lngrowK_oconf = strofreal( ( exp(`ln08' + lngrow_oconf[1,6]) - exp(`ln08') ) / 1000, "%9.1f")
noisily di as txt strofreal(lngrow_oconf[1,6] * 100,"%9.1f") + " log points is the income growth, which equals around `lngrowK_oconf'K for competitive & overconfident according to the regression in Table XI (2)"

eststo tab11III: reg lnsalary_grow 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

eststo tab11IV: reg lnsalary_grow 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r

noisily di " "
noisily esttab tab11I tab11II tab11III tab11IV, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "p P-val" "r2 R-sqrt") sfmt(0 2 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab11I tab11II tab11III tab11IV using "tableXI.tex", replace keep(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "r2 \$R^2\$") sfmt(0 3 3)  mgroups("Without Industry Fixed Effects" "With Industry Fixed Effects", pattern(1 0 1 0) prefix(\multicolumn{@span}{c}{) span suffix(}) erepeat(\cmidrule(lr){@span}))
noisily di " "


// Prepare regressions for Table XII. The code outputs the table and makes the tex version. Note that the marginal effects for the interaction term are calculated as the change of two marginal effects. Namely, the marginal effect of 'overconfidence' when 'competitive' equals one and the one when 'competitive' equals zero (all other variables at means). The standard error and p-value correspond to testing whether these marginal effects are significantly different from each other.
// ******************************************************************************************************************
noisily di as err "*** Table XII – Correlates of income in 2015 and preferences of competition and overconfidence ***"
// ******************************************************************************************************************

foreach var in hourswork numjobs numpromotions{
	egen `var'_std = std(`var') if lnsalary15 < .
}
la var hourswork_std "Hours worked per week"
la var numjobs_std "Number of jobs"
la var numpromotions_std "Number of promotions"

eststo tab12AI: reg numjobs_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
eststo tab12AII: reg numjobs_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std, r

eststo tab12AIII: reg numpromotions_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
eststo tab12AIV: reg numpromotions_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std, r

eststo tab12AV: reg hourswork_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  mat coef = e(b)
  sum hourswork15 if e(sample)
  local stdeffect = strofreal( coef[1,3] * r(sd),"%9.1f")
  noisily di as txt "One standard deviation increase in overconfidence means `stdeffect' hours worked"
eststo tab12AVI: reg hourswork_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std, r

probit workbreak i.gender i.competitive c.overconf_std c.riskCRRA_std c.perform_std, r
  local orgchi2 = round(e(chi2),0.001)
  eststo tab12AVII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std) atmeans post
  estadd local Ochi2 `orgchi2'
probit workbreak i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/6{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,7] = coef2[1,1]
  mat coef[1,9] = coef2[1,2] - coef2[1,1]
  mat vars[7,7] = vars2[1,1]
  mat vars[9,9] = (coef[1,9]/invnormal(`pval'/2))^2
  probit workbreak i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab12AVIII

  probit workbreak i.gender i.competitive c.riskCRRA_std c.perform_std c.overconf_std i.competitive#c.overconf_std, r
  margins competitive, at(overconf_std=(-1 0 1))
  mat coef = r(b)
  sum workbreak if e(sample)
  noisily di as txt strofreal(r(mean),"%9.3f") + " is the mean probability of carreer interruption"
  noisily di as txt strofreal(coef[1,2],"%9.3f") + " is the mean probability of carreer interruption for competitive & underconfident according to the regression in Table XII Panel A (8)"
  noisily di as txt strofreal(coef[1,6],"%9.3f") + " is the mean probability of carreer interruption for competitive & overconfident according to the regression in Table XII Panel A (8)"

eststo tab12BI: reg numjobs_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r
eststo tab12BII: reg numjobs_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std ib0.ind15, r

eststo tab12BIII: reg numpromotions_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r
eststo tab12BIV: reg numpromotions_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std ib0.ind15, r

eststo tab12BV: reg hourswork_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r
eststo tab12BVI: reg hourswork_std 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std ib0.ind15, r

probit workbreak i.gender i.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15, r
  local orgchi2 = strofreal(e(chi2),"%9.3f")
  eststo tab12BVII: margins, dydx(1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std ib0.ind15) atmeans post
  estadd local Ochi2 `orgchi2'
probit workbreak i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind15 c.overconf_std i.competitive#c.overconf_std, r
  mat coef = e(b)
  mat vars = e(V)
  margins, dydx(1.gender 1.competitive c.riskCRRA_std c.perform_std ib0.ind15) atmeans
  mat coef1 = r(b)
  mat vars1 = r(V)
  margins competitive, dydx(c.overconf_std) atmeans post
  mat coef2 = e(b)
  mat vars2 = e(V)
  test 1.competitive = 0.competitive
  local pval = r(p)
  forvalues x=1/9{
    mat coef[1,`x'] = coef1[1,`x']
    mat vars[`x',`x'] = vars1[`x',`x']
  }
  mat coef[1,10] = coef2[1,1]
  mat coef[1,12] = coef2[1,2] - coef2[1,1]
  mat vars[10,10] = vars2[1,1]
  mat vars[12,12] = (coef[1,12]/invnormal(`pval'/2))^2
  probit workbreak i.gender i.competitive c.riskCRRA_std c.perform_std ib0.ind15 c.overconf_std i.competitive#c.overconf_std, r
  erepost b = coef
  erepost V = vars
  eststo tab12BVIII

noisily di as err "Panel A – Without industry fixed effects"
noisily esttab tab12AI tab12AII tab12AIII tab12AIV tab12AV tab12AVI tab12AVII tab12AVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "Ochi2 Org-Chi2" "chi2 Chi2-test" "r2 R-sqrt" ) sfmt(0 3 3 3 3) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab12AI tab12AII tab12AIII tab12AIV tab12AV tab12AVI tab12AVII tab12AVIII using "tableXII.tex", replace keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{1.5}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "Ochi2 \$\chi^2\$ test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3)  mgroups("Number of jobs" "Number of promotions" "Hours worked per week" "Career interruption", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) span suffix(}) erepeat(\cmidrule(lr){@span}))
noisily di " "

noisily di as err "Panel B – With industry fixed effects"
noisily esttab tab12BI tab12BII tab12BIII tab12BIV tab12BV tab12BVI tab12BVII tab12BVIII, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "chi2 Chi2-test" "r2 R-sqrt" "Ochi2 Org-Chi2") sfmt(0 2 2 3 2) replace nodep nomti keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label

// esttab tab12BI tab12BII tab12BIII tab12BIV tab12BV tab12BVI tab12BVII tab12BVIII using "tableXII.tex", append keep(1.gender 1.competitive overconf_std riskCRRA_std 1.competitive#c.overconf_std) order(1.gender 1.competitive overconf_std 1.competitive#c.overconf_std riskCRRA_std) label booktabs nogaps noobs nonotes nomtitle alignment(d{1.5}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "Ochi2 \$\chi^2\$ test" "chi2 \$\chi^2\$ test" "r2 \$R^2\$") sfmt(0 3 3 3 3)  mgroups("Number of jobs" "Number of promotions" "Hours worked per week" "Career interruption", pattern(1 0 1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) span suffix(}) erepeat(\cmidrule(lr){@span}))
noisily di " "


// Prepare regressions for Table XIII and XIV. The code outputs the table and makes the tex version.
// *********************************************************************************************************************************************************************
noisily di as err "*** Table XIII – Career paths and the effect of preferences of competition and overconfidence on income in 2015 (without industry fixed effects) ***"
// *********************************************************************************************************************************************************************

eststo tab13I: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std numjobs_std, r
eststo tab13II: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std numpromotions_std, r
eststo tab13III: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std hourswork_std, r
eststo tab13IV: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std 1.workbreak, r
eststo tab13V: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std numjobs_std numpromotions_std 1.workbreak hourswork_std, r

eststo tab14I: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std numjobs_std ib0.ind15, r
eststo tab14II: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std numpromotions_std ib0.ind15, r
eststo tab14III: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std hourswork_std ib0.ind15, r
eststo tab14IV: reg lnsalary15 1.gender 1.competitive c.overconf_std 1.competitive#c.overconf_std c.riskCRRA_std c.perform_std 1.workbreak ib0.ind15, r
eststo tab14V: reg lnsalary15 1.gender 1.competitive c.overconf_std c.riskCRRA_std c.perform_std 1.competitive#c.overconf_std numjobs_std numpromotions_std hourswork_std 1.workbreak ib0.ind15, r

noisily esttab tab13I tab13II tab13III tab13IV tab13V, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "r2 R-sqrt") sfmt(0 2 3) replace nodep nomti drop(perform_std _cons) label

// esttab tab13I tab13II tab13III tab13IV tab13V using "tableXIII.tex", replace drop(perform_std _cons) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "r2 \$R^2\$") sfmt(0 3 3)

// *****************************************************************************************************************************************************************
noisily di as err "*** Table XIV – Career paths and the effect of preferences of competition and overconfidence on income in 2015 (with industry fixed effects) ***"
// *****************************************************************************************************************************************************************

noisily esttab tab14I tab14II tab14III tab14IV tab14V, cells(b(star fmt(3)) se(par fmt(3))) star(* 0.10 ** 0.05 *** 0.01) scalars("N Observations" "F F-test" "r2 R-sqrt") sfmt(0 2 3) replace nodep nomti drop(perform_std _cons 0.ind15 1.ind15 2.ind15) label

// esttab tab14I tab14II tab14III tab14IV tab14V using "tableXIV.tex", replace drop(perform_std _cons 0.ind15 1.ind15 2.ind15) label booktabs nogaps noobs nonotes nomtitle alignment(d{2.6}) b(3) se(3) star(* 0.10 ** 0.05 *** 0.01) scalars("N Obs." "F \textit{F}-test" "r2 \$R^2\$") sfmt(0 3 3)

}
